@@ -80,6 +80,9 @@ ALL_ROUTES = [
     ('block:access-list', 'SoftLayer.CLI.block.access.list:cli'),
     ('block:access-revoke', 'SoftLayer.CLI.block.access.revoke:cli'),
     ('block:access-password', 'SoftLayer.CLI.block.access.password:cli'),
+    ('block:subnets-list', 'SoftLayer.CLI.block.subnets.list:cli'),
+    ('block:subnets-assign', 'SoftLayer.CLI.block.subnets.assign:cli'),
+    ('block:subnets-remove', 'SoftLayer.CLI.block.subnets.remove:cli'),
     ('block:replica-failback', 'SoftLayer.CLI.block.replication.failback:cli'),
     ('block:replica-failover', 'SoftLayer.CLI.block.replication.failover:cli'),
     ('block:replica-order', 'SoftLayer.CLI.block.replication.order:cli'),
@@ -102,6 +105,7 @@ ALL_ROUTES = [
     ('block:volume-modify', 'SoftLayer.CLI.block.modify:cli'),
     ('block:volume-order', 'SoftLayer.CLI.block.order:cli'),
     ('block:volume-set-lun-id', 'SoftLayer.CLI.block.lun:cli'),
+    ('block:volume-limits', 'SoftLayer.CLI.block.limit:cli'),
 
     ('event-log', 'SoftLayer.CLI.event_log'),
     ('event-log:get', 'SoftLayer.CLI.event_log.get:cli'),
@@ -132,6 +136,7 @@ ALL_ROUTES = [
     ('file:volume-list', 'SoftLayer.CLI.file.list:cli'),
     ('file:volume-modify', 'SoftLayer.CLI.file.modify:cli'),
     ('file:volume-order', 'SoftLayer.CLI.file.order:cli'),
+    ('file:volume-limits', 'SoftLayer.CLI.file.limit:cli'),
 
     ('firewall', 'SoftLayer.CLI.firewall'),
     ('firewall:add', 'SoftLayer.CLI.firewall.add:cli'),
@@ -234,6 +239,7 @@ ALL_ROUTES = [
     ('hardware:rescue', 'SoftLayer.CLI.hardware.power:rescue'),
     ('hardware:ready', 'SoftLayer.CLI.hardware.ready:cli'),
     ('hardware:toggle-ipmi', 'SoftLayer.CLI.hardware.toggle_ipmi:cli'),
+    ('hardware:dns-sync', 'SoftLayer.CLI.hardware.dns:cli'),
 
     ('securitygroup', 'SoftLayer.CLI.securitygroup'),
     ('securitygroup:list', 'SoftLayer.CLI.securitygroup.list:cli'),
