@@ -364,6 +364,7 @@ getValidSecurityCertificates = getSecurityCertificates
 getTickets = [
     {
         "accountId": 1234,
+        "serviceProviderResourceId": "CS123456",
         "assignedUserId": 12345,
         "createDate": "2013-08-01T14:14:04-07:00",
         "id": 100,
@@ -379,6 +380,7 @@ getTickets = [
     },
     {
         "accountId": 1234,
+        "serviceProviderResourceId": "CS123456",
         "assignedUserId": 12345,
         "createDate": "2013-08-01T14:14:04-07:00",
         "id": 101,
@@ -394,6 +396,7 @@ getTickets = [
     },
     {
         "accountId": 1234,
+        "serviceProviderResourceId": "CS123456",
         "assignedUserId": 12345,
         "createDate": "2014-03-03T09:44:01-08:00",
         "id": 102,
@@ -766,3 +769,86 @@ getApplicationDeliveryControllers = [
         }
     }
 ]
+
+getScaleGroups = [
+    {
+        "accountId": 31111,
+        "cooldown": 1800,
+        "createDate": "2016-10-25T01:48:34+08:00",
+        "id": 12222222,
+        "lastActionDate": "2016-10-25T01:48:34+08:00",
+        "maximumMemberCount": 5,
+        "minimumMemberCount": 0,
+        "name": "tests",
+        "regionalGroupId": 663,
+        "virtualGuestMemberTemplate": {
+            "accountId": 31111,
+            "domain": "sodg.com",
+            "hostname": "testing",
+            "id": None,
+            "maxCpu": None,
+            "maxMemory": 32768,
+            "startCpus": 32,
+            "blockDevices": [
+                {
+                    "device": "0",
+                    "diskImage": {
+                        "capacity": 25,
+                    }
+                }
+            ],
+            "datacenter": {
+                "name": "sao01",
+            },
+            "hourlyBillingFlag": True,
+            "operatingSystemReferenceCode": "CENTOS_LATEST",
+        },
+        "virtualGuestMemberCount": 0,
+        "status": {
+            "id": 1,
+            "keyName": "ACTIVE",
+            "name": "Active"
+        },
+    },
+    {
+        "accountId": 31111,
+        "cooldown": 1800,
+        "createDate": "2018-04-24T04:22:00+08:00",
+        "id": 224533333,
+        "lastActionDate": "2019-01-19T04:53:18+08:00",
+        "maximumMemberCount": 10,
+        "minimumMemberCount": 0,
+        "modifyDate": "2019-01-19T04:53:21+08:00",
+        "name": "test-ajcb",
+        "regionalGroupId": 1025,
+        "virtualGuestMemberTemplate": {
+            "accountId": 31111,
+            "domain": "test.local",
+            "hostname": "autoscale-ajcb01",
+            "id": None,
+            "maxCpu": None,
+            "maxMemory": 1024,
+            "postInstallScriptUri": "http://test.com",
+            "startCpus": 1,
+            "blockDevices": [
+                {
+                    "device": "0",
+                    "diskImage": {
+                        "capacity": 25,
+                    }
+                }
+            ],
+            "datacenter": {
+                "name": "seo01",
+            },
+            "hourlyBillingFlag": True,
+            "operatingSystemReferenceCode": "CENTOS_7_64",
+        },
+        "virtualGuestMemberCount": 0,
+        "status": {
+            "id": 1,
+            "keyName": "ACTIVE",
+            "name": "Active"
+        }
+    }
+]
